import { Component, OnInit } from '@angular/core';
import { BPMNFlowSet } from 'src/app/models/bpmn-flow-set';
import { BPMNFlow } from 'src/app/models/bpmn-flow';
import { FlowService } from 'src/app/services/flow.service';
import { FileService } from 'src/app/services/file.service';
import { Router, ActivatedRoute } from '@angular/router';
import { TestService } from 'src/app/services/test.service';
import { BPMNTestcase } from 'src/app/models/bpmn-testcase';

@Component({
  selector: 'app-flow',
  templateUrl: './flow.component.html',
  styleUrls: ['./flow.component.css']
})
export class FlowComponent implements OnInit {

  actualProject: number;
  flowSet: BPMNFlowSet;
  testcases: Array<BPMNTestcase>;
  diagram: string;
  isFlowLoading: boolean;
  isDiagramLoading: boolean;
  isTestsLoading: boolean;
  isDeleteLoading: boolean;
  activeFlow: BPMNFlow;
  actualFlow: string;

  constructor(private flowService: FlowService, private testService: TestService, private fileService: FileService, private router: Router, private route: ActivatedRoute) { 
    this.route.params.subscribe(params => {
      this.actualProject = params['projectId'];
      this.actualFlow = params['flowId'];
    })
  }

  async ngOnInit() {
    await this.loadFlow();
    await this.loadBPMNDiagram();
    await this.loadTests();
  }

  async loadFlow() {
    this.isFlowLoading = true;
    try {
      let result = await this.flowService.getFlow(this.actualProject, this.actualFlow);
      this.activeFlow = result;
    } finally {
      this.isFlowLoading = false;
    }
  }

  async loadTests() {
    this.isTestsLoading = true;
    try {
      let result = await this.testService.getTests(this.actualProject, this.actualFlow);
      this.testcases = result;
    } finally {
      this.isTestsLoading = false;
    }
  }

  async loadBPMNDiagram() {
    this.isDiagramLoading = true;
    try {
      let result = await this.fileService.getBPMNDiagram(this.actualProject);
      this.diagram = result;
    } finally {
      this.isDiagramLoading = false;
    }
  }

  async deleteTest(deleteTest: string) {
    this.isDeleteLoading = true;
    try {
      await this.testService.deleteTest(this.actualProject, deleteTest);
    } finally {
      await this.loadTests();
      this.isDeleteLoading = false;
    }
  }
}
