import { Component, OnInit } from '@angular/core';
import { BPMNFlowSet } from 'src/app/models/bpmn-flow-set';
import { BPMNFlow } from 'src/app/models/bpmn-flow';
import { FlowService } from 'src/app/services/flow.service';
import { FileService } from 'src/app/services/file.service';
import { Router, ActivatedRoute } from '@angular/router';
import { ProjectService } from 'src/app/services/project.service';
import { SingleProjectConfig } from 'src/app/models/single-project-config';

@Component({
  selector: 'app-flows',
  templateUrl: './flows.component.html',
  styleUrls: ['./flows.component.css']
})
export class FlowsComponent implements OnInit {

  actualProject: number;
  actualProjectConfig: SingleProjectConfig;
  flowSet: BPMNFlowSet;
  diagram: string;
  isProjectLoading: boolean;
  isFlowLoading: boolean;
  isDiagramLoading: boolean;
  activeFlow: BPMNFlow;

  detailFlowVisible: boolean = false;

  constructor(private flowService: FlowService, private projectService: ProjectService, private fileService: FileService, private router: Router, private route: ActivatedRoute) { 
    this.route.params.subscribe(params =>
      this.actualProject = params['projectId']
    )
  }

  async ngOnInit() {
    await this.loadProject();
    await this.loadFlows();
    await this.loadBPMNDiagram();
  }

  async loadProject() {
    this.isProjectLoading = true;
    try {
      let result = await this.projectService.getProject(this.actualProject);
      this.actualProjectConfig = result;
    } finally {
      this.isProjectLoading = false;
    }
  }

  async loadFlows() {
    this.isFlowLoading = true;
    try {
      let result = await this.flowService.getFlows(this.actualProject);
      this.flowSet = result;
      this.activeFlow = this.flowSet.flows[0];
    } finally {
      this.isFlowLoading = false;
    }
  }

  async loadBPMNDiagram() {
    this.isDiagramLoading = true;
    try {
      let result = await this.fileService.getBPMNDiagram(this.actualProject);
      this.diagram = result;
    } finally {
      this.isDiagramLoading = false;
    }
  }

  async highlight(flow: BPMNFlow) {
    this.activeFlow = flow;
    window.scrollTo(0, 0);
  }

  async onFlowVisibility() {
    this.detailFlowVisible = !this.detailFlowVisible;
  }
}
