import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { HttpClient } from '@angular/common/http';
import { SingleProjectConfig } from '../models/single-project-config';
import { ProjectCreation } from '../models/project-creation';
import { Loop } from '../models/loop';

@Injectable({
  providedIn: 'root'
})
export class ProjectService {

  constructor(public http: HttpClient) { }

  public async getProject(projectId: number): Promise<SingleProjectConfig> {
    const url = `${environment.apiBaseUrl}project/${projectId}`;
    return <SingleProjectConfig>await this.http.get(url).toPromise();
  }

  public async getProjects(): Promise<Array<SingleProjectConfig>> {
    const url = `${environment.apiBaseUrl}project`;
    return <Array<SingleProjectConfig>>await this.http.get(url).toPromise();
  }

  public async createProject(project: ProjectCreation): Promise<any> {
    const url = `${environment.apiBaseUrl}project`;
    return await this.http.post<any>(url, project).toPromise();
  }

  public async initLoop(projectId: number): Promise<Array<Loop>> {
    const url = `${environment.apiBaseUrl}project/${projectId}/initLoop`;
    return <Array<Loop>>await this.http.post(url, null).toPromise();
  }

  public async initProject(projectId: number): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}/initTest`;
    return await this.http.post<any>(url, null).toPromise();
  }

  public async deleteProject(projectId: number): Promise<any> {
    const url = `${environment.apiBaseUrl}project/${projectId}`;
    return await this.http.delete<any>(url).toPromise();
  }
}
